Type: Package
Package: multilevelPSA
Title: Multilevel Propensity Score Analysis
Version: 1.3.1
Date: 2025-11-17
Authors@R: 
    person("Jason", "Bryer", , "jason@bryer.org", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-2454-0402"))
Description: Conducts and visualizes propensity score analysis for
    multilevel, or clustered data. Bryer & Pruzek (2011)
    <doi:10.1080/00273171.2011.636693>.
License: GPL (>= 2)
URL: https://jbryer.github.io/multilevelPSA/
BugReports: https://github.com/jbryer/multilevelPSA/issues/
Depends: ggplot2, R (>= 3.0), xtable
Imports: grid, MASS, party, plyr, PSAgraphics, psych, reshape
Suggests: knitr, MatchIt, mice, rmarkdown, testthat
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-11-17 15:38:33 UTC; jbryer
Author: Jason Bryer [aut, cre] (ORCID: <https://orcid.org/0000-0002-2454-0402>)
Maintainer: Jason Bryer <jason@bryer.org>
Repository: CRAN
Date/Publication: 2025-11-17 16:00:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:09:21 UTC; unix
