# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,covariate.balance)
S3method(grid::drawDetails,zeroGrob)
S3method(grid::grobHeight,zeroGrob)
S3method(grid::grobWidth,zeroGrob)
S3method(grid::heightDetails,zeroGrob)
S3method(grid::widthDetails,zeroGrob)
S3method(plot,covariate.balance)
S3method(plot,mlpsa)
S3method(plot,psrange)
S3method(print,covariate.balance)
S3method(print,mlpsa)
S3method(print,psrange)
S3method(print,xmlpsa)
S3method(summary,mlpsa)
S3method(summary,psrange)
S3method(xtable,mlpsa)
export(covariate.balance)
export(difftable.plot)
export(getPropensityScores)
export(getStrata)
export(is.mlpsa)
export(loess.plot)
export(lsos)
export(missing.plot)
export(mlpsa)
export(mlpsa.circ.plot)
export(mlpsa.ctree)
export(mlpsa.difference.plot)
export(mlpsa.distribution.plot)
export(mlpsa.logistic)
export(psrange)
export(tree.plot)
import(PSAgraphics)
import(ggplot2)
import(party)
import(plyr)
import(xtable)
importFrom(MASS,stepAIC)
importFrom(grid,editGrob)
importFrom(grid,gTree)
importFrom(grid,getGrob)
importFrom(grid,grid.draw)
importFrom(grid,grid.layout)
importFrom(grid,grid.newpage)
importFrom(grid,grob)
importFrom(grid,grobHeight)
importFrom(grid,grobWidth)
importFrom(grid,pushViewport)
importFrom(grid,unit.c)
importFrom(grid,upViewport)
importFrom(grid,viewport)
importFrom(grid,vpPath)
importFrom(grid,vpTree)
importFrom(psych,describeBy)
importFrom(reshape,cast)
importFrom(reshape,melt)
importFrom(reshape,melt.data.frame)
importFrom(stats,binomial)
importFrom(stats,density)
importFrom(stats,fitted)
importFrom(stats,glm)
importFrom(stats,median)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,sd)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,object.size)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
