pisa.psa.cols <- c(
	"ST04Q01", #Sex
	"ST05Q01", #Attend 1=No; 2=Yes, <1 year; 3=Yes, >1 year
	"ST06Q01", #Age
	"ST07Q01", #Repeat 1=No, 2=Yes once; 3=Yes two or more
	"ST08Q01", #At home mother 1=Yes; 2=No
	"ST08Q02", #At home father 1=Yes; 2=No
	"ST08Q03", #At home brothers 1=Yes; 2=No
	"ST08Q04", #At home sisters
	"ST08Q05", #At home grandparents
	"ST08Q06", #At home others
	"ST10Q01", #Mother highest schooling
	"ST12Q01", #Mother current job status 1=Full-time; 2=Part-time; 3=Looking for work; 4=Other
	"ST14Q01", #Father highest schooling
	"ST16Q01", #Father current job status
	"ST19Q01", #Language at home 1=Language of test; 2=Another language
	"ST20Q01", #Desk
	"ST20Q02", #Own room
	"ST20Q03", #Study place
	"ST20Q04", #Computer
	"ST20Q05", #Software
	"ST20Q06", #Internet
	"ST20Q07", #Literature
	"ST20Q08", #Poetry
	"ST20Q09", #Art
	"ST20Q10", #Textbooks
	"ST20Q12", #Dictionary
	"ST20Q13", #Dishwasher
	"ST20Q14", #DVD
	"ST21Q01", #How many cellphones
	"ST21Q02", #How may TVs
	"ST21Q03", #How many computers
	"ST21Q04", #How many cars
	"ST21Q05", #How many rooms bath or shower
	"ST22Q01", #How many books 1=0-10; 2=11-25; 3=26-100; 4=101-200; 5=201-500; 6= >500
	"ST23Q01", #Reading enjoyment time 1=Don't read; 2= <30 minutes/day; 3=1-2 hours/day; 4= >2hours/day
	"ST31Q01", #Enrich in test language
	"ST31Q02", #Enrich in mathematics
	"ST31Q03", #Enrich in science
	"ST31Q05", #Remedial in test language
	"ST31Q06", #Remedial in mathematics
	"ST31Q07", #Remedial in science
	"ST32Q01", #Out of school lessons in test language
	"ST32Q02", #Out of school lessons <maths> 1	Do not attend 2	Less than 2 hours a week 3	2 up to 4 Hours a week 4	4 up to 6 hours per week 5	6 or more hours a week 7	N/A 8	Invalid 9	Miss
	"ST32Q03" #Out of school lessons in science
)
