context("PISA")

test_that("PISA data loads from package", {
# 	data(pisa.school)
# 	expect_that(school.orig, is_a('data.frame'))
# 	expect_that(ncol(school.orig), equals(247))
# 	expect_that(nrow(school.orig), equals(17145))
})


